# Guide

Manage notebooks interactively:

- {doc}`quickstart`
- {doc}`guide/received`
- {doc}`guide/basic-metadata`
- {doc}`guide/update-metadata`

Build on the metadata API:

- {doc}`guide/meta`

```{toctree}
:maxdepth: 1
:hidden:

quickstart
guide/received
guide/basic-metadata
guide/update-metadata
guide/meta
```
